@@ -21,7 +21,7 @@ from eli5.sklearn import PermutationImportance
 import numpy as np
 from sklearn.model_selection import learning_curve
 from sklearn.model_selection import ShuffleSplit
-from drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
+from simba.drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
 
 def train_multimodel(configini):
     pd.options.mode.chained_assignment = None
@@ -274,6 +274,7 @@ def train_multimodel(configini):
             if generate_features_importance_bar_graph == 'yes':
                 print('Generating feature importance log...')
                 importances = list(clf.feature_importances_)
+                generate_features_importance_log = 'yes'
                 log_df = generateFeatureImportanceLog(importances, classifierName, saveFileNo)
                 print('Generating feature importance bar graph...')
                 generateFeatureImportanceBarGraph(log_df, N_feature_importance_bars, classifierName, saveFileNo)
